import { WebGPUObjectError } from '../utils/errors.js'

export class BindGroup {
  _device: GPUDevice
  _handle: GPUBindGroup

  get handle() {
    return this._handle
  }

  /**
   * @param {GPUDevice} device
   * @param {GPUBindGroup} bindGroup
   */
  constructor(device: GPUDevice, bindGroup: GPUBindGroup) {
    this._device = device
    this._handle = bindGroup
  }

  static create(device: GPUDevice, descriptor: GPUBindGroupDescriptor) {
    try {
      return new BindGroup(
        device,
        device.createBindGroup(descriptor)
      )
    } catch (err) {
      throw WebGPUObjectError.from(err, BindGroup)
    }
  }

  destroy() {
    this._handle = null
  }
}

