import { Buffer } from './buffer.js'

interface GeometryDescriptor {
  vertices: Buffer
  vertexCount: number
  layout: GPUVertexBufferLayout
  indices?: Buffer
  indexCount?: number
  format?: GPUIndexFormat
}

export class Geometry {
  _device: GPUDevice
  _vertices: Buffer
  _vertexCount: number
  _vertexBufferLayout: GPUVertexBufferLayout
  _indices: Buffer
  _indexCount: number
  _format: string

  constructor(device: GPUDevice, descriptor: GeometryDescriptor) {
    this._device = device
    this._vertices = descriptor.vertices
    this._vertexCount = descriptor.vertexCount
    this._vertexBufferLayout = descriptor.layout

    if (descriptor.indices) {
      this._indices = descriptor.indices
      this._indexCount = descriptor.indexCount
      this._format = descriptor.format

      if (this._indexCount == null || this._format == null) {
        throw new Error('indexCount or format is required when creating an indexed geometry')
      }
    }
  }
}

