import { WebGPUObjectError } from '../utils/errors.js'
import { ResourceType } from '../utils/internal-enums.js'

/** @import { BindGroupEntry } from '../core/graphics-device.js' */

export class Sampler {
  _device: GPUDevice
  _handle: GPUSampler

  get handle() {
    return this._handle
  }

  get label() {
    return this._handle.label
  }

  get resourceType() {
    return ResourceType.Sampler
  }

  constructor(device: GPUDevice, sampler: GPUSampler) {
    this._device = device
    this._handle = sampler
  }

  static create(device: GPUDevice, descriptor: GPUSamplerDescriptor) {
    try {
      return new Sampler(
        device,
        device.createSampler(descriptor)
      )
    } catch (err) {
      throw WebGPUObjectError.from(err, Sampler)
    }
  }

  toBindingResource() {
    return this._handle
  }
}

